@@ -4,7 +4,7 @@ import pandas as pd
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
 
-from greykite.framework.templates.autogen.forecast_config import ForecastConfig, MetadataParam, EvaluationPeriodParam
+from greykite.framework.templates.autogen.forecast_config import ForecastConfig, MetadataParam, EvaluationPeriodParam, ComputationParam
 from greykite.framework.templates.forecaster import Forecaster
 from greykite.framework.templates.model_templates import ModelTemplateEnum
 from xgboost import XGBRegressor
@@ -12,6 +12,7 @@ from sklearn.ensemble import RandomForestRegressor
 from statsmodels.tsa.statespace.sarimax import SARIMAX
 
 from amendment_forecast import utils
+# import utils
 
 # TODO Define loss_functions enum
 LOSS_FUNCTIONS = [
@@ -104,7 +105,9 @@ class FBProphet(BaseModel):
     def __init__(self):
         """Initializes prophet model"""
         super().__init__()
-        self.metadata = MetadataParam(time_col=DATE_COLUMN_NAME, value_col=VALUE_COLUMN_NAME)
+        self.metadata = MetadataParam(
+            time_col=DATE_COLUMN_NAME,
+            value_col=VALUE_COLUMN_NAME)
 
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str, forecast_period_list: list) -> tuple:
         """Runs rolling prediction using the model to return actual and predicted values
@@ -125,7 +128,7 @@ class FBProphet(BaseModel):
         result = forecaster.run_forecast_config(  # result is also stored as `forecaster.forecast_result`.
             df=dataframe,
             config=ForecastConfig(
-                evaluation_period_param=EvaluationPeriodParam(test_horizon=test_horizon),
+                evaluation_period_param=EvaluationPeriodParam(test_horizon=test_horizon, cv_horizon=0),
                 model_template=ModelTemplateEnum.PROPHET.name,
                 coverage=0.95,
                 metadata_param=self.metadata,
@@ -152,6 +155,7 @@ class Naive(BaseModel):
         self.minimum_training_years = 2
 
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str, forecast_period_list: list) -> tuple:
+        dataframe_in = dataframe.set_index("period")
         # Determine training and testing periods to create test and training dataframes
         comparison_period_relativedelta = relativedelta(years=self.growth_comparison_period_in_years)
         train_mask = dataframe[DATE_COLUMN_NAME] <= train_end
@@ -196,10 +200,16 @@ class Naive(BaseModel):
         for timestamp in forecast_period_list:
             forecast_value = run_prediction(timestamp)
             forecast.append(forecast_value)
-            new_row = pd.DataFrame({DATE_COLUMN_NAME: [timestamp], VALUE_COLUMN_NAME: [forecast_value]})
+            new_row = pd.DataFrame({DATE_COLUMN_NAME: [timestamp], "yhat": [forecast_value]})
             dataframe = pd.concat([dataframe, new_row]).reset_index(drop=True)
+            mask = dataframe[VALUE_COLUMN_NAME].isnull()
+            dataframe.loc[mask, VALUE_COLUMN_NAME] = dataframe.loc[mask, "yhat"]
 
-        return actual, predicted, forecast
+        dataframe_test["predicted"] = predicted
+        dataframe_test = dataframe_test.set_index("period")
+        dataframe = dataframe.set_index("period")
+
+        return dataframe_test[VALUE_COLUMN_NAME], dataframe_test["predicted"], dataframe["yhat"]
 
 
 class XGBoost(BaseModel):
@@ -316,7 +326,7 @@ class RandomForest(BaseModel):
         return result_df
 
     def step_forecast(self, train_df: pd.DataFrame, test_x: pd.DataFrame, feature_columns: list):
-        # fit an xgboost model and make a one step prediction
+        # fit a rf model and make a one step prediction
         # split into input and output columns
         train_x = train_df[feature_columns]
         train_y = train_df[VALUE_COLUMN_NAME]
@@ -444,7 +454,6 @@ class SARIMA(BaseModel):
         train_mask = dataframe.index <= train_end
         train = dataframe[train_mask]
         test = dataframe[~train_mask]
-
         # Step over each time period and get result
         for index, row in test.iterrows():
             # fit model on history and make a prediction
